@@ -19,7 +19,11 @@
 #' )
 #' has_endmark(x)
 has_endmark <- function(x, endmarks = c('?', '.', '!'), ...){
-    !is.na(x) & grepl(sprintf('[%s]\\s*$', paste(endmarks, collapse = "")), x, ...)
+    !is.na(x) & grepl(
+        sprintf('[%s]\\s*$', paste(endmarks, collapse = "")), 
+        x, 
+        ...
+    )
 }
 
 
