@@ -5,7 +5,7 @@ test_that("replace_emoticon converts emoticons to words",{
 
     x <- lexicon::hash_emoticons[[1]][16]
 
-    expect_equal(replace_emoticon(x), " sad ")
+    expect_equal(replace_emoticon(x), " devilish ")
 
 })
 
